==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/display/renderbasic/src/test/java/org/openscience/cdk/renderer/elements/BoundsTest.java <==
/*
 * Copyright (c) 2013 European Bioinformatics Institute (EMBL-EBI)
 *                    John May <jwmay@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or (at
 * your option) any later version. All we ask is that proper credit is given
 * for our work, which includes - but is not limited to - adding the above
 * copyright notice to the beginning of your source code files, and to any
 * copyright notice that you may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 U
 */

package org.openscience.cdk.renderer.elements;

import org.junit.BeforeClass;
import org.junit.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.number.IsCloseTo.closeTo;

/**
 * @author John May
 * @cdk.module test-renderbasic
 */
public class BoundsTest extends AbstractElementTest {

    @BeforeClass
    public static void setup() {
        setRenderingElement(new Bounds(0, 0, 0, 0));
    }

    @Test
    public void width() throws Exception {
        assertThat(new Bounds(2, 2, 7, 6).width(), is(closeTo(5d, 0.1)));
    }

    @Test
    public void testHeight() throws Exception {
        assertThat(new Bounds(2, 2, 7, 6).height(), is(closeTo(4d, 0.1)));
    }
}

==> cdk_2.10.orig.tar.gz: cdk-cdk-2.10/display/renderbasic/src/test/java/org/openscience/cdk/renderer/elements/BoundsTest.java <==
/*
 * Copyright (c) 2013 European Bioinformatics Institute (EMBL-EBI)
 *                    John May <jwmay@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or (at
 * your option) any later version. All we ask is that proper credit is given
 * for our work, which includes - but is not limited to - adding the above
 * copyright notice to the beginning of your source code files, and to any
 * copyright notice that you may distribute with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 U
 */

package org.openscience.cdk.renderer.elements;

import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.number.IsCloseTo.closeTo;

/**
 * @author John May
 * @cdk.module test-renderbasic
 */
class BoundsTest extends AbstractElementTest {

    @BeforeAll
    static void setup() {
        setRenderingElement(new Bounds(0, 0, 0, 0));
    }

    @Test
    void width() throws Exception {
        assertThat(new Bounds(2, 2, 7, 6).width(), is(closeTo(5d, 0.1)));
    }

    @Test
    void testHeight() throws Exception {
        assertThat(new Bounds(2, 2, 7, 6).height(), is(closeTo(4d, 0.1)));
    }
}
